# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.1] - WIP

### Added
- Added ability to the declared cluster span limit
- Added Flae8 & Bandit Linters
- Added Synk vulnerability analysis
- Added Pyup & CII best practise Badges

### Updated
- README documentation update for pypi
- Updated Makefile Issues


## [1.0.0] - 2021-06-06

### Added

- This CHANGELOG file to hopefully serve as an evolving example of a
  standardized open source project CHANGELOG.
- Good examples and basic guidelines

